{% extends "cradmin_legacy/standalone-base.django.html" %}
{% load i18n %}

{% block body %}
    <div class="container">
        <h1>{% trans "Permission denied" %}</h1>
        <p>
            {% trans "You do not have permission to access this page." %}
        </p>
    </div>
{% endblock body %}
