{% load cradmin_legacy_image_tags %}
{% load i18n %}

<p>
    {% cradmin_create_archiveimage_tag archiveimage=archiveimage imagetype=imagetype css_class='img-responsive' fallbackoptions=fallbackoptions %}
</p>
