{% block outer-wrapper %}
    <div class="{{ me.get_css_classes_string }}">
        {% block content %}
            {{ me.value }}
        {% endblock content %}
    </div>
{% endblock outer-wrapper %}
