{% extends "cradmin_legacy/layouts/standalone/focused.django.html" %}
{% load i18n %}

{% block title %}
    {% trans "Reset password" %}
    -
    {% block subtitle %}{% endblock subtitle %}
{% endblock title %}
