{% extends "cradmin_legacy/viewhelpers/objecttable/objecttable.django.html" %}
{% load crispy_forms_tags %}

{% block content %}
    <div class="cradmin-legacy-form-wrapper">
        {% crispy form formhelper %}
    </div>

    {{ block.super }}
{% endblock content %}
